class C4AccountSettings:
	GREENSCREENS_RATE_IN_RFP = 'GREENSCREENS_RATE_IN_RFP'
	CAPACITY_DATA_IN_RFP = 'CAPACITY_DATA_IN_RFP'
	SEARCH_TRUCK_ORIGIN_DEADHEAD_LIMIT = 'SEARCH_TRUCK_ORIGIN_DEADHEAD_LIMIT'
	SEARCH_TRUCK_DESTINATION_DEADHEAD_LIMIT = 'SEARCH_TRUCK_DESTINATION_DEADHEAD_LIMIT'
	SEARCH_TRUCK_RESULTS_COUNT = 'SEARCH_TRUCK_RESULTS_COUNT'
	INCLUDE_DISPATCHER_IN_BOOK_NOW_OFFER = 'INCLUDE_DISPATCHER_IN_BOOK_NOW_OFFER'
	AUTO_INVITE_CARRIERS = 'AUTO_INVITE_CARRIERS'
